Struct signal_hook_registry::SigId [−][src]
pub struct SigId { /* fields omitted */ }Expand description
An ID of registered action.
This is returned by all the registration routines and can be used to remove the action later on
with a call to unregister.