Function register_sigaction

unsafe fn register_sigaction<F>(signal: c_int, action: F) -> Result<SigId, Error>
where
    F: Fn(&siginfo_t) + Sync + Send + 'static

Register a signal action.

This acts in the same way as register, including the drawbacks, panics and performance characteristics. The only difference is the provided action accepts a siginfo_t argument, providing information about the received signal.

Safety

See the details of register.