Struct SigId

struct SigId { ... }

An ID of registered action.

This is returned by all the registration routines and can be used to remove the action later on with a call to unregister.

Implementations

impl Clone for SigId

fn clone(self: &Self) -> SigId

impl Copy for SigId

impl Debug for SigId

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for SigId

impl Freeze for SigId

impl Hash for SigId

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for SigId

fn cmp(self: &Self, other: &SigId) -> Ordering

impl PartialEq for SigId

fn eq(self: &Self, other: &SigId) -> bool

impl PartialOrd for SigId

fn partial_cmp(self: &Self, other: &SigId) -> Option<Ordering>

impl RefUnwindSafe for SigId

impl Send for SigId

impl StructuralPartialEq for SigId

impl Sync for SigId

impl Unpin for SigId

impl UnsafeUnpin for SigId

impl UnwindSafe for SigId

impl<T> Any for SigId

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SigId

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SigId

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SigId

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SigId

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SigId

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SigId

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SigId

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SigId

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>